@@ -5,11 +5,12 @@ module JsImagePaths
 
     initializer('js_image_paths.compile', after: 'sprockets.environment') do |application|
       sprockets_env = application.assets || Sprockets
-      sprockets_env.register_preprocessor('application/javascript', :'js_image_path.compile') do |context, data|
+      sprockets_env.register_preprocessor('application/javascript', :'js_image_path.compile') do |input|
+        context = input[:environment].context_class.new(input)
         if context.logical_path == 'js_image_paths'
           JsImagePaths::Generator.context = context
         end
-        data
+        {data: input[:data]}
       end
     end
   end
